![PyPI](https://img.shields.io/pypi/v/pyTesyCloud.svg?color=green&style=for-the-badge)

# pyTesyCloud

Library for Tesy smart home devices. Connects through the mytesy portal.

Based on the StyraHem/pyTesy library for water heaters.

# Support devices
- Water heater
- electric heater
